@@ -2,13 +2,13 @@ package config
 
 import (
 	"bytes"
+	"encoding/json"
 	"io"
 	"os"
 	"strings"
 
-	json "github.com/goccy/go-json"
 	toml "github.com/pelletier/go-toml/v2"
-	yaml "gopkg.in/yaml.v3"
+	yaml "go.yaml.in/yaml/v3"
 )
 
 func (cfg *Config) Backup() {
@@ -71,12 +71,6 @@ func (cfg *Config) Export(format string) string {
 	return ""
 }
 
-func (cfg *Config) BackupAndMigrate() {
-	cfg.Backup()
-	cfg.Migrate()
-	cfg.Write(cfg.Format)
-}
-
 func (cfg *Config) Write(format string) {
 	content := cfg.Export(format)
 	if content == "" {
