@@ -34,7 +34,7 @@ const (
 	UPGRADENOTICE = "notice"
 	RELOAD        = "reload"
 
-	Version = 3
+	Version = 4
 )
 
 type Action string
@@ -79,7 +79,6 @@ type Config struct {
 	ShellIntegration        bool `json:"shell_integration,omitempty" toml:"shell_integration,omitempty" yaml:"shell_integration,omitempty"`
 	FinalSpace              bool `json:"final_space,omitempty" toml:"final_space,omitempty" yaml:"final_space,omitempty"`
 	UpgradeNotice           bool `json:"-" toml:"-" yaml:"-"`
-	updated                 bool
 	extended                bool
 	PatchPwshBleed          bool `json:"patch_pwsh_bleed,omitempty" toml:"patch_pwsh_bleed,omitempty" yaml:"patch_pwsh_bleed,omitempty"`
 	AutoUpgrade             bool `json:"-" toml:"-" yaml:"-"`
@@ -175,7 +174,7 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 
 		for _, segment := range block.Segments {
 			if segment.Type == AZ {
-				source := segment.Properties.GetString(segments.Source, segments.FirstMatch)
+				source := segment.Options.String(segments.Source, segments.FirstMatch)
 				if strings.Contains(source, segments.Pwsh) {
 					log.Debug("azure enabled")
 					feats |= shell.Azure
@@ -183,7 +182,7 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 			}
 
 			if segment.Type == GIT {
-				source := segment.Properties.GetString(segments.Source, segments.Cli)
+				source := segment.Options.String(segments.Source, segments.Cli)
 				if source == segments.Pwsh {
 					log.Debug("posh-git enabled")
 					feats |= shell.PoshGit
@@ -198,11 +197,6 @@ func (cfg *Config) Features(env runtime.Environment) shell.Features {
 func (cfg *Config) upgradeFeatures() shell.Features {
 	var feats shell.Features
 
-	if _, OK := cache.Get[string](cache.Device, upgrade.CACHEKEY); OK && !cfg.Upgrade.Force {
-		log.Debug("upgrade cache key found and not forced, skipping upgrade")
-		return feats
-	}
-
 	autoUpgrade := cfg.Upgrade.Auto
 	if val, OK := cache.Get[bool](cache.Device, AUTOUPGRADE); OK {
 		log.Debug("auto upgrade key found, overriding config")
@@ -231,3 +225,38 @@ func (cfg *Config) upgradeFeatures() shell.Features {
 func (cfg *Config) Hash() uint64 {
 	return cfg.hash
 }
+
+// migrateSegmentProperties migrates the deprecated Properties field to Options for all segments.
+// This is needed for TOML configs since go-toml/v2 doesn't support custom unmarshalers.
+func (cfg *Config) migrateSegmentProperties() {
+	for _, block := range cfg.Blocks {
+		for _, segment := range block.Segments {
+			segment.MigratePropertiesToOptions()
+		}
+	}
+}
+
+// toggleSegments processes all segments in all blocks and adds segments
+// with Toggled == true to the toggle cache, effectively toggling them off.
+func (cfg *Config) toggleSegments() {
+	currentToggleSet, _ := cache.Get[map[string]bool](cache.Session, cache.TOGGLECACHE)
+	if currentToggleSet == nil {
+		currentToggleSet = make(map[string]bool)
+	}
+
+	for _, block := range cfg.Blocks {
+		for _, segment := range block.Segments {
+			if segment.Toggled {
+				segmentName := segment.Alias
+				if segmentName == "" {
+					segmentName = string(segment.Type)
+				}
+
+				currentToggleSet[segmentName] = true
+			}
+		}
+	}
+
+	// Update cache with the map directly
+	cache.Set(cache.Session, cache.TOGGLECACHE, currentToggleSet, cache.INFINITE)
+}
