@@ -10,14 +10,14 @@ func (az *AzFunc) Template() string {
 
 func (az *AzFunc) Enabled() bool {
 	az.extensions = []string{"host.json", "local.settings.json", "function.json"}
-	az.commands = []*cmd{
-		{
-
+	az.tooling = map[string]*cmd{
+		"func": {
 			executable: "func",
 			args:       []string{"--version"},
 			regex:      `(?P<version>[0-9.]+)`,
 		},
 	}
+	az.defaultTooling = []string{"func"}
 
 	return az.Language.Enabled()
 }
