@@ -4,8 +4,8 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 )
 
 type Node struct {
@@ -17,15 +17,15 @@ type Node struct {
 
 const (
 	// PnpmIcon illustrates PNPM is used
-	PnpmIcon properties.Property = "pnpm_icon"
+	PnpmIcon options.Option = "pnpm_icon"
 	// YarnIcon illustrates Yarn is used
-	YarnIcon properties.Property = "yarn_icon"
+	YarnIcon options.Option = "yarn_icon"
 	// NPMIcon illustrates NPM is used
-	NPMIcon properties.Property = "npm_icon"
+	NPMIcon options.Option = "npm_icon"
 	// BunIcon illustrates Bun is used
-	BunIcon properties.Property = "bun_icon"
+	BunIcon options.Option = "bun_icon"
 	// FetchPackageManager shows if Bun, NPM, PNPM, or Yarn is used
-	FetchPackageManager properties.Property = "fetch_package_manager"
+	FetchPackageManager options.Option = "fetch_package_manager"
 )
 
 func (n *Node) Template() string {
@@ -34,13 +34,14 @@ func (n *Node) Template() string {
 
 func (n *Node) Enabled() bool {
 	n.extensions = []string{"*.js", "*.ts", "package.json", ".nvmrc", "pnpm-workspace.yaml", ".pnpmfile.cjs", ".vue"}
-	n.commands = []*cmd{
-		{
+	n.tooling = map[string]*cmd{
+		"node": {
 			executable: "node",
 			args:       []string{"--version"},
 			regex:      `(?:v(?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+))))`,
 		},
 	}
+	n.defaultTooling = []string{"node"}
 	n.versionURLTemplate = "https://github.com/nodejs/node/blob/master/doc/changelogs/CHANGELOG_V{{ .Major }}.md#{{ .Full }}"
 	n.Language.matchesVersionFile = n.matchesVersionFile
 	n.Language.loadContext = n.loadContext
@@ -49,14 +50,14 @@ func (n *Node) Enabled() bool {
 }
 
 func (n *Node) loadContext() {
-	if !n.props.GetBool(FetchPackageManager, false) {
+	if !n.options.Bool(FetchPackageManager, false) {
 		return
 	}
 
 	packageManagerDefinitions := []struct {
 		fileName     string
 		name         string
-		iconProperty properties.Property
+		iconProperty options.Option
 		defaultIcon  string
 	}{
 		{
@@ -100,7 +101,7 @@ func (n *Node) loadContext() {
 	for _, pm := range packageManagerDefinitions {
 		if n.env.HasFiles(pm.fileName) {
 			n.PackageManagerName = pm.name
-			n.PackageManagerIcon = n.props.GetString(pm.iconProperty, pm.defaultIcon)
+			n.PackageManagerIcon = n.options.String(pm.iconProperty, pm.defaultIcon)
 			break
 		}
 	}
