@@ -10,33 +10,34 @@ func (r *Ruby) Template() string {
 
 func (r *Ruby) Enabled() bool {
 	r.extensions = []string{"*.rb", "Rakefile", "Gemfile"}
-	r.commands = []*cmd{
-		{
+	r.tooling = map[string]*cmd{
+		"rbenv": {
 			executable: "rbenv",
 			args:       []string{"version-name"},
 			regex:      `(?P<version>.+)`,
 		},
-		{
+		"rvm-prompt": {
 			executable: "rvm-prompt",
 			args:       []string{"i", "v", "g"},
 			regex:      `(?P<version>.+)`,
 		},
-		{
+		"chruby": {
 			executable: "chruby",
 			args:       []string(nil),
 			regex:      `\* (?P<version>.+)\n`,
 		},
-		{
+		"asdf": {
 			executable: "asdf",
 			args:       []string{"current", "ruby"},
 			regex:      `ruby\s+(?P<version>[^\s]+)\s+`,
 		},
-		{
+		"ruby": {
 			executable: "ruby",
 			args:       []string{"--version"},
 			regex:      `ruby\s+(?P<version>[^\s]+)\s+`,
 		},
 	}
+	r.defaultTooling = []string{"rbenv", "rvm-prompt", "chruby", "asdf", "ruby"}
 
 	enabled := r.Language.Enabled()
 
