@@ -4,8 +4,8 @@ import (
 	"testing"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 
@@ -29,7 +29,7 @@ func TestStatusWriterEnabled(t *testing.T) {
 		env.On("StatusCodes").Return(tc.Status, "")
 		env.On("Shell").Return(shell.GENERIC)
 
-		props := properties.Map{}
+		props := options.Map{}
 		if len(tc.Template) > 0 {
 			props[StatusTemplate] = tc.Template
 		}
@@ -95,7 +95,7 @@ func TestFormatStatus(t *testing.T) {
 	}
 
 	for _, tc := range cases {
-		props := properties.Map{
+		props := options.Map{
 			StatusTemplate:  tc.Template,
 			StatusSeparator: tc.Separator,
 		}
