@@ -3,10 +3,16 @@ package template
 import (
 	"fmt"
 	link "net/url"
+	"slices"
 )
 
-// url builds an hyperlink if url is not empty, otherwise returns the text only
+// url builds a hyperlink if url is not empty, otherwise returns the text only
 func url(text, url string) (string, error) {
+	unsupported := []string{elvish, xonsh}
+	if slices.Contains(unsupported, shell) {
+		return text, nil
+	}
+
 	if url == "" {
 		return text, nil
 	}
@@ -17,6 +23,11 @@ func url(text, url string) (string, error) {
 	return fmt.Sprintf("<LINK>%s<TEXT>%s</TEXT></LINK>", url, text), nil
 }
 
-func path(text, path string) (string, error) {
+func filePath(text, path string) (string, error) {
+	unsupported := []string{elvish, xonsh}
+	if slices.Contains(unsupported, shell) {
+		return text, nil
+	}
+
 	return fmt.Sprintf("<LINK>file:%s<TEXT>%s</TEXT></LINK>", path, text), nil
 }
